==> nextcloud-27.1.2.tgz: nextcloud/apps/serverinfo/l10n/et_EE.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Protsessori info pole saadaval",
    "Load average: {cpu} (last minute)" : "Keskmine koormus: {cpu} (last minute)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "Mälu: Kokku: {memTotalBytes}/Kasutusel: {memUsageBytes}",
    "RAM info not available" : "Vahemälu info pole saadaval",
    "Not supported!" : "Pole toetatud!",
    "Press ⌘-C to copy." : "Kopeerimiseks vajuta ⌘+C.",
    "Press Ctrl-C to copy." : "Kopeerimiseks vajuta Ctrl+C.",
    "System" : "Süsteem",
    "Monitoring" : "Monitooring",
    "Monitoring app with useful server information" : "Monitoorimisrakendus kasuliku infoga serveri kohta",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Näitab kasulikku infot serveri kohta, näiteks protsessori koormus, mälukasutus, kettaruum, kasutajate arv jne.",
    "Operating System:" : "Operatsioonisüsteem:",
    "CPU:" : "Protsessor:",
    "Unknown Processor" : "Tundmatu protsessor",
    "Memory:" : "Vahemälu:",
    "Server time:" : "Serveri aeg:",
    "Uptime:" : "Aktiivaeg:",
    "Temperature" : "Temperatuur",
    "Load" : "Koormus",
    "Memory" : "Vahemälu",
    "Disk" : "Ketas",
    "Mount:" : "Maunt:",
    "Filesystem:" : "Failisüsteem:",
    "Size:" : "Suurus:",
    "Available:" : "Saadaval:",
    "Used:" : "Kasutusel:",
    "Files:" : "Faile:",
    "Free Space:" : "Vaba ruum:",
    "Network" : "Võrk",
    "Hostname:" : "Hostinimi:",
    "DNS:" : "Nimeserver:",
    "Gateway:" : "Võrgulüüs:",
    "Status:" : "Seisund:",
    "Speed:" : "Kiirus:",
    "Duplex:" : "Dupleks:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Aktiivseid kasutajaid",
    "Total users:" : "Kasutajaid kokku:",
    "24 hours:" : "24 tundi:",
    "1 hour:" : "1 tund:",
    "5 mins:" : "5 minutit:",
    "Shares" : "Jaoskaustad",
    "Users:" : "Kasutajaid:",
    "Groups:" : "Gruppe:",
    "Links:" : "Linke:",
    "Emails:" : "E-kirju:",
    "PHP" : "PHP",
    "Version:" : "Versioon:",
    "Memory limit:" : "Mälulimiit:",
    "Max execution time:" : "Maksimaalne täitmisaeg:",
    "Upload max size:" : "Maksimaalne üleslaadimissuurus:",
    "Extensions:" : "Laiendused:",
    "Unable to list extensions" : "Laienduste loetlemine ebaõnnestus",
    "Database" : "Andmebaas",
    "Type:" : "Tüüp:",
    "External monitoring tool" : "Väline monitoorimistööriist",
    "You can connect an external monitoring tool by using this end point:" : "Saad välise monitoorimistööriista ühendada selle lõpp-punkti abil:",
    "Copy" : "Kopeeri",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Lisades URL-i lõppu \"?format=json\", saad tulemused JSON-formaadis.",
    "To use an access token, please generate one then set it using the following command:" : "Ligipääsutunnuse kasutamiseks genereeri see ja seadista alljärgneva käsu abil:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Seejärel saada tunnus ülaloleva URL-i pärimisel \"NC-Token\" päisega.",
    "You will get a notification once one of your disks is nearly full." : "Saad teavituse, kui mõni ketastest on peaaegu täis."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.4.tgz: nextcloud/apps/serverinfo/l10n/et_EE.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Protsessori info pole saadaval",
    "Load average: {cpu} (last minute)" : "Keskmine koormus: {cpu} (last minute)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "Mälu: Kokku: {memTotalBytes}/Kasutusel: {memUsageBytes}",
    "RAM info not available" : "Vahemälu info pole saadaval",
    "Copied!" : "Kopeeritud!",
    "Not supported!" : "Pole toetatud!",
    "Press ⌘-C to copy." : "Kopeerimiseks vajuta ⌘+C.",
    "Press Ctrl-C to copy." : "Kopeerimiseks vajuta Ctrl+C.",
    "System" : "Süsteem",
    "Monitoring" : "Monitooring",
    "Monitoring app with useful server information" : "Monitoorimisrakendus kasuliku infoga serveri kohta",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Näitab kasulikku infot serveri kohta, näiteks protsessori koormus, mälukasutus, kettaruum, kasutajate arv jne.",
    "Operating System:" : "Operatsioonisüsteem:",
    "CPU:" : "Protsessor:",
    "Unknown Processor" : "Tundmatu protsessor",
    "Memory:" : "Vahemälu:",
    "Server time:" : "Serveri aeg:",
    "Uptime:" : "Aktiivaeg:",
    "Temperature" : "Temperatuur",
    "Load" : "Koormus",
    "Memory" : "Vahemälu",
    "Disk" : "Ketas",
    "Mount:" : "Maunt:",
    "Filesystem:" : "Failisüsteem:",
    "Size:" : "Suurus:",
    "Available:" : "Saadaval:",
    "Used:" : "Kasutusel:",
    "Files:" : "Faile:",
    "Free Space:" : "Vaba ruum:",
    "Network" : "Võrk",
    "Hostname:" : "Hostinimi:",
    "DNS:" : "Nimeserver:",
    "Gateway:" : "Võrgulüüs:",
    "Status:" : "Seisund:",
    "Speed:" : "Kiirus:",
    "Duplex:" : "Dupleks:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Aktiivseid kasutajaid",
    "Total users:" : "Kasutajaid kokku:",
    "24 hours:" : "24 tundi:",
    "1 hour:" : "1 tund:",
    "5 mins:" : "5 minutit:",
    "Shares" : "Jaoskaustad",
    "Users:" : "Kasutajaid:",
    "Groups:" : "Gruppe:",
    "Links:" : "Linke:",
    "Emails:" : "E-kirju:",
    "PHP" : "PHP",
    "Version:" : "Versioon:",
    "Memory limit:" : "Mälulimiit:",
    "Max execution time:" : "Maksimaalne täitmisaeg:",
    "Upload max size:" : "Maksimaalne üleslaadimissuurus:",
    "Extensions:" : "Laiendused:",
    "Unable to list extensions" : "Laienduste loetlemine ebaõnnestus",
    "Database" : "Andmebaas",
    "Type:" : "Tüüp:",
    "External monitoring tool" : "Väline monitoorimistööriist",
    "Copy" : "Kopeeri",
    "To use an access token, please generate one then set it using the following command:" : "Ligipääsutunnuse kasutamiseks genereeri see ja seadista alljärgneva käsu abil:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "Seejärel saada tunnus ülaloleva URL-i pärimisel \"NC-Token\" päisega.",
    "You will get a notification once one of your disks is nearly full." : "Saad teavituse, kui mõni ketastest on peaaegu täis.",
    "You can connect an external monitoring tool by using this end point:" : "Saad välise monitoorimistööriista ühendada selle lõpp-punkti abil:",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Lisades URL-i lõppu \"?format=json\", saad tulemused JSON-formaadis."
},
"nplurals=2; plural=(n != 1);");
